@@ -158,9 +158,9 @@ class Nag_Api extends Horde_Registry_Api
 
         $name = $tasklist->getName();
         if (!empty($params['synchronize'])) {
-            $sync = @unserialize($prefs->getValue('sync_lists'));
+            $sync = @unserialize($GLOBALS['prefs']->getValue('sync_lists'));
             $sync[] = $name;
-            $prefs->setValue('sync_lists', serialize($sync));
+            $GLOBALS['prefs']->setValue('sync_lists', serialize($sync));
         }
 
         return $name;
@@ -244,7 +244,7 @@ class Nag_Api extends Horde_Registry_Api
      */
     public function browse($path = '', $properties = array())
     {
-        global $registry;
+        global $injector, $nag_shares, $registry;
 
         // Default properties.
         if (!$properties) {
@@ -256,6 +256,7 @@ class Nag_Api extends Horde_Registry_Api
         }
         $path = trim($path, '/');
         $parts = explode('/', $path);
+        $currentUser = $registry->getAuth();
 
         if (empty($path)) {
             // This request is for a list of all users who have tasklists
@@ -263,42 +264,34 @@ class Nag_Api extends Horde_Registry_Api
             $tasklists = Nag::listTasklists(false, Horde_Perms::READ);
             $owners = array();
             foreach ($tasklists as $tasklist) {
-                $owners[$tasklist->get('owner') ? $tasklist->get('owner') : '-system-'] = true;
+                $owners[$tasklist->get('owner') ? $registry->convertUsername($tasklist->get('owner'), false) : '-system-'] = $tasklist->get('owner') ?: '-system-';
             }
 
             $results = array();
-            foreach (array_keys($owners) as $owner) {
+            foreach ($owners as $externalOwner => $internalOwner) {
                 if (in_array('name', $properties)) {
-                    $results['nag/' . $owner]['name'] = $owner;
+                    $results['nag/' . $externalOwner]['name'] = $injector
+                        ->getInstance('Horde_Core_Factory_Identity')
+                        ->create($internalOwner)
+                        ->getName();
                 }
                 if (in_array('icon', $properties)) {
-                    $results['nag/' . $owner]['icon'] = Horde_Themes::img('user.png');
+                    $results['nag/' . $externalOwner]['icon'] = Horde_Themes::img('user.png');
                 }
                 if (in_array('browseable', $properties)) {
-                    $results['nag/' . $owner]['browseable'] = true;
+                    $results['nag/' . $externalOwner]['browseable'] = true;
                 }
-                if (in_array('contenttype', $properties)) {
-                    $results['nag/' . $owner]['contenttype'] =
-                        'httpd/unix-directory';
-                }
-                if (in_array('contentlength', $properties)) {
-                    $results['nag/' . $owner]['contentlength'] = 0;
-                }
-                if (in_array('modified', $properties)) {
-                    $results['nag/' . $owner]['modified'] =
-                        $_SERVER['REQUEST_TIME'];
-                }
-                if (in_array('created', $properties)) {
-                    $results['nag/' . $owner]['created'] = 0;
+                if (in_array('read-only', $properties)) {
+                    $results['nag/' . $externalOwner]['read-only'] = true;
                 }
             }
             return $results;
 
         } elseif (count($parts) == 1) {
             // This request is for all tasklists owned by the requested user
-            $owner = $parts[0] == '-system-' ? '' : $parts[0];
-            $tasklists = $GLOBALS['nag_shares']->listShares(
-                $GLOBALS['registry']->getAuth(),
+            $owner = $parts[0] == '-system-' ? '' : $registry->convertUsername($parts[0], true);
+            $tasklists = $nag_shares->listShares(
+                $currentUser,
                 array('perm' => Horde_Perms::SHOW,
                       'attributes' => $owner));
 
@@ -312,32 +305,27 @@ class Nag_Api extends Horde_Registry_Api
                     $results[$retpath]['name'] = sprintf(_("Tasks from %s"), Nag::getLabel($tasklist));
                     $results[$retpath . '.ics']['name'] = Nag::getLabel($tasklist);
                 }
+                if (in_array('displayname', $properties)) {
+                    $results[$retpath]['displayname'] = Nag::getLabel($tasklist);
+                    $results[$retpath . '.ics']['displayname'] = Nag::getLabel($tasklist) . '.ics';
+                }
+                if (in_array('owner', $properties)) {
+                    $results[$retpath]['owner'] = $results[$retpath . '.ics']['owner'] = $tasklist->get('owner') ? $registry->convertUsername($tasklist->get('owner'), false) : '-system-';
+                }
                 if (in_array('icon', $properties)) {
                     $results[$retpath]['icon'] = Horde_Themes::img('nag.png');
                     $results[$retpath . '.ics']['icon'] = Horde_Themes::img('mime/icalendar.png');
                 }
                 if (in_array('browseable', $properties)) {
-                    $results[$retpath]['browseable'] = $tasklist->hasPermission($GLOBALS['registry']->getAuth(), Horde_Perms::READ);
+                    $results[$retpath]['browseable'] = $tasklist->hasPermission($currentUser, Horde_Perms::READ);
                     $results[$retpath . '.ics']['browseable'] = false;
                 }
+                if (in_array('read-only', $properties)) {
+                    $results[$retpath]['read-only'] = $results[$retpath . '.ics']['read-only'] = !$tasklist->hasPermission($currentUser, Horde_Perms::EDIT);
+                }
                 if (in_array('contenttype', $properties)) {
-                    $results[$retpath]['contenttype'] = 'httpd/unix-directory';
                     $results[$retpath . '.ics']['contenttype'] = 'text/calendar';
                 }
-                if (in_array('contentlength', $properties)) {
-                    $results[$retpath]['contentlength'] = 0;
-                    $results[$retpath . '.ics']['contentlength'] = strlen($this->exportTasklist($tasklistId, 'text/calendar'));
-                }
-                if (in_array('modified', $properties)) {
-                    // @TODO Find a way to get the actual modification times
-                    $results[$retpath]['modified'] = $_SERVER['REQUEST_TIME'];
-                    $results[$retpath . '.ics']['modified'] = $_SERVER['REQUEST_TIME'];
-                }
-                if (in_array('created', $properties)) {
-                    // @TODO Find a way to get the actual creation times
-                    $results[$retpath]['created'] = 0;
-                    $results[$retpath . '.ics']['created'] = 0;
-                }
             }
             return $results;
 
@@ -359,19 +347,29 @@ class Nag_Api extends Horde_Registry_Api
 
         } elseif (count($parts) == 2) {
             //
-            // This request is browsing into a specific tasklist.  Generate the list
-            // of items and represent them as files within the directory.
+            // This request is browsing into a specific tasklist.  Generate the
+            // list of items and represent them as files within the directory.
             //
-            if (!Nag::hasPermission($parts[1], Horde_Perms::READ)) {
+            try {
+                $tasklist = $nag_shares->getShare($parts[1]);
+            } catch (Horde_Exception_NotFound $e) {
+                throw new Nag_Exception(_("Invalid task list requested."), 404);
+            } catch (Horde_Share_Exception $e) {
+                throw new Nag_Exception($e->getMessage, 500);
+            }
+            if (!$tasklist->hasPermission($currentUser, Horde_Perms::READ)) {
                 throw new Nag_Exception(_("Invalid task list requested."), 404);
             }
-            $storage = $GLOBALS['injector']->getInstance('Nag_Factory_Driver')->create($parts[1]);
+            $storage = $injector->getInstance('Nag_Factory_Driver')->create($parts[1]);
             try {
                 $storage->retrieve();
             } catch (Nag_Exception $e) {
                  throw new Nag_Exception($e->getMessage, 500);
             }
             $icon = Horde_Themes::img('nag.png');
+            $owner = $tasklist->get('owner')
+                ? $registry->convertUsername($tasklist->get('owner'), false)
+                : '-system-';
             $results = array();
             $storage->tasks->reset();
             while ($task = $storage->tasks->each()) {
@@ -379,24 +377,21 @@ class Nag_Api extends Horde_Registry_Api
                 if (in_array('name', $properties)) {
                     $results[$key]['name'] = $task->name;
                 }
+                if (in_array('owner', $properties)) {
+                    $results[$key]['owner'] = $owner;
+                }
                 if (in_array('icon', $properties)) {
                     $results[$key]['icon'] = $icon;
                 }
                 if (in_array('browseable', $properties)) {
                     $results[$key]['browseable'] = false;
                 }
+                if (in_array('read-only', $properties)) {
+                    $results[$key]['read-only'] = !$tasklist->hasPermission($currentUser, Horde_Perms::EDIT);
+                }
                 if (in_array('contenttype', $properties)) {
                     $results[$key]['contenttype'] = 'text/calendar';
                 }
-                if (in_array('contentlength', $properties)) {
-                    // FIXME:  This is a hack.  If the content length is longer
-                    // than the actual data then some WebDAV clients will report
-                    // an error when the file EOF is received.  Ideally we should
-                    // determine the actual size of the data and report it here, but
-                    // the performance hit may be prohibitive.  This requires
-                    // further investigation.
-                    $results[$key]['contentlength'] = 1;
-                }
                 if (in_array('modified', $properties)) {
                     $results[$key]['modified'] = $this->modified($task->uid, $parts[1]);
                 }
@@ -415,10 +410,11 @@ class Nag_Api extends Horde_Registry_Api
                 // This request is for a specific item within a given task list.
                 //
                 /* Create a Nag storage instance. */
-                $storage = $GLOBALS['injector']->getInstance('Nag_Factory_Driver')->create($parts[1]);
+                $storage = $injector->getInstance('Nag_Factory_Driver')
+                    ->create($parts[1]);
                 $storage->retrieve();
                 try {
-                    $storage->get($parts[2]);
+                    $task = $storage->get($parts[2]);
                 } catch (Nag_Exception $e) {
                     throw new Nag_Exception($e->getMessage(), 500);
                 }
@@ -430,12 +426,6 @@ class Nag_Api extends Horde_Registry_Api
                     $result['mtime'] = $modified;
                 }
                 return $result;
-            } elseif (count($parts) == 2 &&
-                substr($parts[1], -4) == '.ics' &&
-                Nag::hasPermission(substr($parts[1], 0, -4), Horde_Perms::READ)) {
-
-                // ??
-
             } else {
                 //
                 // All other requests are a 404: Not Found
@@ -464,36 +454,38 @@ class Nag_Api extends Horde_Registry_Api
 
         if (count($parts) == 2 &&
             substr($parts[1], -4) == '.ics') {
-
-                // Workaround for WebDAV clients that are not smart enough to send
-                // the right content type.  Assume text/calendar.
-                if ($content_type == 'application/octet-stream') {
-                    $content_type = 'text/calendar';
-                }
-                $tasklist = substr($parts[1], 0, -4);
-            } elseif (count($parts) == 3) {
-                $tasklist = $parts[1];
-
-                // Workaround for WebDAV clients that are not smart enough to send
-                // the right content type.  Assume the same format we send individual
-                // tasklist items: text/calendar
-                if ($content_type == 'application/octet-stream') {
-                    $content_type = 'text/calendar';
-                }
-            } else {
-                throw new Nag_Exception(_("Invalid task list name supplied."), 403);
+            // Workaround for WebDAV clients that are not smart enough to send
+            // the right content type.  Assume text/calendar.
+            if ($content_type == 'application/octet-stream') {
+                $content_type = 'text/calendar';
             }
+            $tasklist = substr($parts[1], 0, -4);
+        } elseif (count($parts) == 3) {
+            $tasklist = $parts[1];
+            // Workaround for WebDAV clients that are not smart enough to send
+            // the right content type.  Assume the same format we send
+            // individual tasklist items: text/calendar
+            if ($content_type == 'application/octet-stream') {
+                $content_type = 'text/calendar';
+            }
+        } else {
+            throw new Nag_Exception(_("Invalid task list name supplied."), 403);
+        }
 
         if (!Nag::hasPermission($tasklist, Horde_Perms::EDIT)) {
-            // FIXME: Should we attempt to create a tasklist based on the filename
-            // in the case that the requested tasklist does not exist?
+            // FIXME: Should we attempt to create a tasklist based on the
+            // filename in the case that the requested tasklist does not exist?
             throw new Nag_Exception(_("Task list does not exist or no permission to edit"), 403);
         }
 
         // Store all currently existings UIDs. Use this info to delete UIDs not
         // present in $content after processing.
         $ids = array();
-        $uids_remove = array_flip($this->listUids($tasklist));
+        if (count($parts) == 2) {
+            $uids_remove = array_flip($this->listUids($tasklist));
+        } else {
+            $uids_remove = array();
+        }
 
         $storage = $GLOBALS['injector']->getInstance('Nag_Factory_Driver')->create($tasklist);
 
@@ -527,9 +519,7 @@ class Nag_Api extends Horde_Registry_Api
                 if (!$create) {
                     // Entry exists, remove from uids_remove list so we
                     // won't delete in the end.
-                    if (isset($uids_remove[$task->uid])) {
-                        unset($uids_remove[$task->uid]);
-                    }
+                    unset($uids_remove[$task->uid]);
                     if ($existing->private &&
                         $existing->owner != $GLOBALS['registry']->getAuth()) {
                         continue;
@@ -551,7 +541,8 @@ class Nag_Api extends Horde_Registry_Api
                                 break;
                             }
                         }
-                    } catch (Exception $e) {}
+                    } catch (Exception $e) {
+                    }
                     if (empty($modified) && !empty($add)) {
                         $modified = $add;
                     }
@@ -613,9 +604,9 @@ class Nag_Api extends Horde_Registry_Api
 
         if (count($parts) == 2) {
             // @TODO Deny deleting of the entire tasklist for now.
-            // Allow users to delete tasklists but not create them via WebDAV will
-            // be more confusing than helpful.  They are, however, still able to
-            // delete individual task items within the tasklist folder.
+            // Allow users to delete tasklists but not create them via WebDAV
+            // will be more confusing than helpful.  They are, however, still
+            // able to delete individual task items within the tasklist folder.
             throw Nag_Exception(_("Deleting entire task lists is not supported."), 403);
             // To re-enable the functionality just remove this if {} block.
         }
