@@ -43,7 +43,7 @@ class Nag_Application extends Horde_Registry_Application
 
     /**
      */
-    public $version = 'H5 (4.2.1)';
+    public $version = 'H5 (4.2.5)';
 
     /**
      * Global variables defined:
@@ -183,7 +183,8 @@ class Nag_Application extends Horde_Registry_Application
                 'edit' => $edit->add('t', $tasklist->getName()),
                 'type' => 'checkbox',
             );
-            if (is_null($tasklist->get('owner'))) {
+            if ($GLOBALS['registry']->isAdmin() &&
+                is_null($tasklist->get('owner'))) {
                 $sidebar->addRow($row, 'system');
             } elseif ($tasklist->get('owner') == $user) {
                 $sidebar->addRow($row, 'my');
@@ -324,7 +325,11 @@ class Nag_Application extends Horde_Registry_Application
                 )
             ));
 
-            foreach (Nag::listTasklists(false, Horde_Perms::EDIT, false) as $name => $tasklist) {
+            $user = $registry->getAuth();
+            foreach (Nag::listTasklists(false, Horde_Perms::SHOW, false) as $name => $tasklist) {
+                if (!$tasklist->hasPermission($user, Horde_Perms::EDIT)) {
+                    continue;
+                }
                 $tree->addNode(array(
                     'id' => $parent . $name . '__new',
                     'parent' => $parent . '__new',
@@ -439,11 +444,11 @@ class Nag_Application extends Horde_Registry_Application
      */
     public function davGetCollections($user)
     {
-        $opts = array('perm' => Horde_Perms::SHOW);
-        $shares = $GLOBALS['nag_shares']
-            ->listShares($user, $opts);
-        $dav = $GLOBALS['injector']
-            ->getInstance('Horde_Dav_Storage');
+        global $injector, $nag_shares, $registry;
+
+        $hordeUser = $registry->convertUsername($user, true);
+        $shares = $nag_shares->listShares($hordeUser);
+        $dav = $injector->getInstance('Horde_Dav_Storage');
         $tasklists = array();
         foreach ($shares as $id => $share) {
             if ($user == '-system-' && $share->get('owner')) {
@@ -460,14 +465,18 @@ class Nag_Application extends Horde_Registry_Application
                     Nag::getUrl(Nag::DAV_CALDAV, $share),
                 'principaluri' => 'principals/' . $user,
                 '{http://sabredav.org/ns}owner-principal' =>
-                    'principals/' . ($share->get('owner') ?: '-system-'),
+                    'principals/'
+                        . ($share->get('owner')
+                           ? $registry->convertUsername($share->get('owner'), false)
+                           : '-system-'
+                        ),
                 '{DAV:}displayname' => Nag::getLabel($share),
                 '{urn:ietf:params:xml:ns:caldav}calendar-description' =>
                     $share->get('desc'),
                 '{http://apple.com/ns/ical/}calendar-color' =>
                     $share->get('color'),
                 '{urn:ietf:params:xml:ns:caldav}supported-calendar-component-set' => new Sabre\CalDAV\Property\SupportedCalendarComponentSet(array('VTODO')),
-                '{http://sabredav.org/ns}read-only' => !$share->hasPermission($user, Horde_Perms::EDIT),
+                '{http://sabredav.org/ns}read-only' => !$share->hasPermission($hordeUser, Horde_Perms::EDIT),
             );
         }
         return $tasklists;
