@@ -278,6 +278,9 @@ class Nag
                 try {
                     $newtasks = $registry->callByPackage($app, 'listAs', array('taskHash'));
                     foreach ($newtasks as $task) {
+                        if (!isset($task['priority'])) {
+                            $task['priority'] = 3;
+                        }
                         $task['tasklist_id'] = '**EXTERNAL**';
                         $task['tasklist_name'] = $registry->get('name', $app);
                         $task = new Nag_Task(null, $task);
@@ -505,6 +508,10 @@ class Nag
             return array();
         }
 
+        if ($owneronly) {
+            return $tasklists;
+        }
+
         $display_tasklists = @unserialize($GLOBALS['prefs']->getValue('display_tasklists'));
         if (is_array($display_tasklists)) {
             foreach ($display_tasklists as $id) {
@@ -724,7 +731,7 @@ class Nag
             }
             $url = Horde::url($url, true, -1)
                 . ($tasklist->get('owner')
-                   ? $tasklist->get('owner')
+                   ? $registry->convertUsername($tasklist->get('owner'), false)
                    : '-system-')
                 . '/' . $tasklist->getName() . '.ics';
             break;
@@ -736,7 +743,7 @@ class Nag
                 $url .= '/rpc.php/calendars/';
             }
             $url = Horde::url($url, true, -1)
-                . $registry->getAuth()
+                . $registry->convertUsername($registry->getAuth(), false)
                 . '/'
                 . $injector->getInstance('Horde_Dav_Storage')
                     ->getExternalCollectionId($tasklist->getName(), 'tasks')
@@ -750,7 +757,7 @@ class Nag
                 $url .= '/rpc.php/';
             }
             $url = Horde::url($url, true, -1)
-                . 'principals/'. $registry->getAuth() . '/';
+                . 'principals/' . $registry->convertUsername($registry->getAuth(), false) . '/';
             break;
         }
 
