@@ -27,6 +27,15 @@ class Nag_Task
      */
     public $tasklist;
 
+    /**
+     * This task's tasklist name.
+     *
+     * Overrides the $tasklist's share name.
+     *
+     * @var string
+     */
+    public $tasklist_name;
+
     /**
      * The task uid.
      *
@@ -546,15 +555,14 @@ class Nag_Task
             $this->completed_date = null;
             $this->completed = false;
             if ($this->recurs()) {
-                /* What do we want do delete here? All completions?
-                 * The latest completion? Any completion in the
-                 * future?. */
-                foreach ($this->recurrence->getCompletions() as $completion) {
-                    $this->recurrence->deleteCompletion(
-                        substr($completion, 0, 4),
-                        substr($completion, 4, 2),
-                        substr($completion, 6, 2));
-                }
+                /* Only delete the latest completion. */
+                $completions = $this->recurrence->getCompletions();
+                sort($completions);
+                list($year, $month, $mday) = sscanf(
+                    end($completions),
+                    '%04d%02d%02d'
+                );
+                $this->recurrence->deleteCompletion($year, $month, $mday);
             }
             return;
         }
@@ -583,6 +591,36 @@ class Nag_Task
         $this->completed = true;
     }
 
+    /**
+     * Returns the next start date of this task.
+     *
+     * Takes recurring tasks into account.
+     *
+     * @return Horde_Date  The next start date.
+     */
+    public function getNextStart()
+    {
+        if (!$this->start) {
+            return null;
+        }
+
+        if (!$this->recurs() ||
+            !($completions = $this->recurrence->getCompletions())) {
+            return new Horde_Date($this->start);
+        }
+
+        sort($completions);
+        list($year, $month, $mday) = sscanf(
+            end($completions),
+            '%04d%02d%02d'
+        );
+        $lastCompletion = new Horde_Date($year, $month, $mday);
+        $recurrence = clone $this->recurrence;
+        $recurrence->start = new Horde_Date($this->start);
+
+        return $recurrence->nextRecurrence($lastCompletion);
+    }
+
     /**
      * Returns the next due date of this task.
      *
@@ -958,6 +996,7 @@ class Nag_Task
     {
         $json = new stdClass;
         $json->l = $this->tasklist;
+        $json->p = $this->parent_id;
         $json->i = $this->indent;
         $json->n = $this->name;
         if ($this->desc) {
@@ -969,9 +1008,8 @@ class Nag_Task
         if ($this->due && ($due = $this->getNextDue())) {
             $json->du = $due->toJson();
         }
-        if ($this->start) {
-            $date = new Horde_Date($this->start);
-            $json->s = $date->toJson();
+        if ($this->start && ($start = $this->getNextStart())) {
+            $json->s = $start->toJson();
         }
         $json->pr = (int)$this->priority;
         if ($this->recurs()) {
@@ -982,7 +1020,6 @@ class Nag_Task
         if ($full) {
             // @todo: do we really need all this?
             $json->id = $this->id;
-            $json->p = $this->parent_id;
             $json->de = $this->desc;
             if ($this->due) {
                 $date = new Horde_Date($this->due);
@@ -1011,7 +1048,7 @@ class Nag_Task
 
             try {
                 $share = $GLOBALS['nag_shares']->getShare($this->tasklist);
-            } catch (Horde_Share_exception $e) {
+            } catch (Horde_Share_Exception $e) {
                 Horde::log($e->getMessage(), 'ERR');
                 throw new Nag_Exception($e);
             }
@@ -1291,6 +1328,9 @@ class Nag_Task
             $message->setRecurrence($this->recurrence);
         }
 
+        /* Categories */
+        $message->categories = $this->tags;
+
         return $message;
     }
 
@@ -1328,9 +1368,11 @@ class Nag_Task
             foreach ($relations as $id => $relation) {
                 if (empty($params[$id]['RELTYPE']) ||
                     Horde_String::upper($params[$id]['RELTYPE']) == 'PARENT') {
-
-                    $parent = $this->_storage->getByUID($relation);
-                    $this->parent_id = $parent->id;
+                    try {
+                        $parent = $this->_storage->getByUID($relation);
+                        $this->parent_id = $parent->id;
+                    } catch (Horde_Exception_NotFound $e) {
+                    }
                     break;
                 }
             }
@@ -1472,6 +1514,11 @@ class Nag_Task
         }
 
         $this->tasklist = $GLOBALS['prefs']->getValue('default_tasklist');
+
+        /* Categories */
+        if (is_array($message->categories) && count($message->categories)) {
+            $this->tags = $message->categories;
+        }
     }
 
 }
