@@ -2,7 +2,7 @@
 /**
  * Create Nag base tables (as of Nag 2.x).
  *
- * Copyright 2010-2014 Horde LLC (http://www.horde.org/)
+ * Copyright 2010-2015 Horde LLC (http://www.horde.org/)
  *
  * See the enclosed file COPYING for license information (GPL). If you
  * did not receive this file, see http://www.horde.org/licenses/gpl.
@@ -50,7 +50,7 @@ class NagBaseTables extends Horde_Db_Migration_Base
         }
 
         if (!in_array('nag_shares', $tableList)) {
-            $t = $this->createTable('nag_shares', array('autoincrementKey' => 'share_id'));
+            $t = $this->createTable('nag_shares', array('autoincrementKey' => false));
             $t->column('share_id', 'integer', array('null' => false));
             $t->column('share_name', 'string', array('null' => false));
             $t->column('share_owner', 'string');
